(*
 *  ==================================================
 *  LAV Splitter Interface for Filter Version 0.58.2
 *  ==================================================
 *
 *  Delphi Translation (date: 11.11.2013):
 *  Martin Offenwanger
 *  Copyright (C) 2013 DSPlayer (R)
 *  http://www.dsplayer.com
 *
 *  Original C++ Code:
 *  Copyright (C) 2010-2013 Hendrik Leppkes
 *  http://www.1f0.de
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with this program; if not, write to the Free Software Foundation, Inc.,
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 *)

unit BTLAVSplitterSettings;

interface

uses
  Windows;

var
  CLSID_LAVSplitter: TGUID = '{171252A0-8820-4AFE-9DF8-5C92B2D66B04}';
  IID_ILAVFSettings: TGUID = '{774A919D-EA95-4A87-8A1E-F48ABE8499C7}';

type

TLAVSubtitleMode = (
  LAVSubtitleMode_NoSubs,
  LAVSubtitleMode_ForcedOnly,
  LAVSubtitleMode_Default,
  LAVSubtitleMode_Advanced
  );

ILAVFSettings = interface(IUnknown)
  ['{774A919D-EA95-4A87-8A1E-F48ABE8499C7}']

  // Switch to Runtime Config mode. This will reset all settings to default,
  // and no changes to the settings will be saved. You can use this to
  // programmatically configure LAV Splitter without interfering with the users
  // settings in the registry. Subsequent calls to this function will reset all
  //  settings back to defaults, even if the mode does not change.
  //
  // Note that calling this function during playback is not supported and may
  // exhibit undocumented behaviour. For smooth operations, it must be called
  // before LAV Splitter opens a file.
  // STDMETHOD(SetRuntimeConfig)(BOOL bRuntimeConfig) = 0;
  function SetRuntimeConfig(bRuntimeConfig: BOOL): HResult; stdcall;

  // Retrieve the preferred languages as ISO 639-2 language codes, comma
  // separated. If the result is NULL, no language has been set
  // Memory for the string will be allocated, and has to be free'ed by the
  // caller with CoTaskMemFree
  // STDMETHOD(GetPreferredLanguages)(LPWSTR *ppLanguages) = 0;
  function GetPreferredLanguages(out ppLanguages: LPWSTR): HResult; stdcall;

  // Set the preferred languages as ISO 639-2 language codes, comma separated
  // To reset to no preferred language, pass NULL or the empty string
  // STDMETHOD(SetPreferredLanguages)(LPCWSTR pLanguages) = 0;
  function SetPreferredLanguages(pLanguages: LPCWSTR): HResult; stdcall;

  // Retrieve the preferred subtitle languages as ISO 639-2 language codes,
  // comma separated. If the result is NULL, no language has been set
  // If no subtitle language is set, the main language preference is used.
  // Memory for the string will be allocated, and has to be free'ed by the
  // caller with CoTaskMemFree
  // STDMETHOD(GetPreferredSubtitleLanguages)(LPWSTR *ppLanguages) = 0;
  function GetPreferredSubtitleLanguages(out ppLanguages: LPWSTR): HResult; stdcall;

  // Set the preferred subtitle languages as ISO 639-2 language codes, comma
  // separated. To reset to no preferred language, pass NULL or the empty string
  // If no subtitle language is set, the main language preference is used.
  // STDMETHOD(SetPreferredSubtitleLanguages)(LPCWSTR pLanguages) = 0;
  function SetPreferredSubtitleLanguages(pLanguages: LPCWSTR): HResult; stdcall;

  // Get the current subtitle mode
  // See enum for possible values
  // STDMETHOD_(LAVSubtitleMode,GetSubtitleMode)() = 0;
  function GetSubtitleMode(): TLAVSubtitleMode; stdcall;

  // Set the current subtitle mode
  // See enum for possible values
  // STDMETHOD(SetSubtitleMode)(LAVSubtitleMode mode) = 0;
  function SetSubtitleMode(mode: TLAVSubtitleMode): HResult; stdcall;

  // Get the subtitle matching language flag
  // TRUE = Only subtitles with a language in the preferred list will be used;
  // FALSE = All subtitles will be used @deprecated - do not use anymore,
  // deprecated and non-functional, replaced by advanced subtitle mode
  // STDMETHOD_(BOOL,GetSubtitleMatchingLanguage)() = 0;
  function GetSubtitleMatchingLanguage(): BOOL; stdcall;

  // Set the subtitle matching language flag
  // TRUE = Only subtitles with a language in the preferred list will be used;
  // FALSE = All subtitles will be used @deprecated - do not use anymore,
  // deprecated and non-functional, replaced by advanced subtitle mode
  // STDMETHOD(SetSubtitleMatchingLanguage)(BOOL dwMode) = 0;
  function SetSubtitleMatchingLanguage(dwMode: BOOL): HResult; stdcall;

  // Control whether a special "Forced Subtitles" stream will be created for
  // PGS subs
  // STDMETHOD_(BOOL,GetPGSForcedStream)() = 0;
  function GetPGSForcedStream(): BOOL; stdcall;

  // Control whether a special "Forced Subtitles" stream will be created for
  // PGS subs
  // STDMETHOD(SetPGSForcedStream)(BOOL bFlag) = 0;
  function SetPGSForcedStream(bFlag: BOOL): HResult; stdcall;

  // Get the PGS forced subs config
  // TRUE = only forced PGS frames will be shown, FALSE = all frames will be
  // shown
  // STDMETHOD_(BOOL,GetPGSOnlyForced)() = 0;
  function GetPGSOnlyForced(): BOOL; stdcall;

  // Set the PGS forced subs config
  // TRUE = only forced PGS frames will be shown, FALSE = all frames will be shown
  // STDMETHOD(SetPGSOnlyForced)(BOOL bForced) = 0;
  function SetPGSOnlyForced(bForced: BOOL): HResult; stdcall;

  // Get the VC-1 Timestamp Processing mode
  // 0 - No Timestamp Correction, 1 - Always Timestamp Correction,
  // 2 - Auto (Correction for Decoders that need it)
  // STDMETHOD_(int,GetVC1TimestampMode)() = 0;
  function GetVC1TimestampMode(): Integer; stdcall;

  // Set the VC-1 Timestamp Processing mode
  // 0 - No Timestamp Correction, 1 - Always Timestamp Correction,
  // 2 - Auto (Correction for Decoders that need it)
  // STDMETHOD(SetVC1TimestampMode)(int iMode) = 0;
  function SetVC1TimestampMode(iMode: Integer): HResult; stdcall;

  // Set whether substreams (AC3 in TrueHD, for example) should be shown as a
  // separate stream
  // STDMETHOD(SetSubstreamsEnabled)(BOOL bSubStreams) = 0;
  function SetSubstreamsEnabled(bSubStreams: BOOL): HResult; stdcall;

  // Check whether substreams (AC3 in TrueHD, for example) should be shown as a
  // separate stream
  // STDMETHOD_(BOOL,GetSubstreamsEnabled)() = 0;
  function GetSubstreamsEnabled(): BOOL; stdcall;

  // @deprecated - no longer required
  // STDMETHOD(SetVideoParsingEnabled)(BOOL bEnabled) = 0;
  function SetVideoParsingEnabled(bEnabled: BOOL): HResult; stdcall;

  // @deprecated - no longer required
  // STDMETHOD_(BOOL,GetVideoParsingEnabled)() = 0;
  function GetVideoParsingEnabled(): BOOL; stdcall;

  // Set if LAV Splitter should try to fix broken HD-PVR streams
  // @deprecated - no longer required
  // STDMETHOD(SetFixBrokenHDPVR)(BOOL bEnabled) = 0;
  function SetFixBrokenHDPVR(bEnabled: BOOL): HResult; stdcall;

  // Query if LAV Splitter should try to fix broken HD-PVR streams
  // @deprecated - no longer required
  // STDMETHOD_(BOOL,GetFixBrokenHDPVR)() = 0;
  function GetFixBrokenHDPVR(): BOOL; stdcall;

  // Control whether the given format is enabled
  // STDMETHOD_(HRESULT,SetFormatEnabled)(LPCSTR strFormat, BOOL bEnabled) = 0;
  function SetFormatEnabled(strFormat: LPCSTR; bEnabled: BOOL): HResult; stdcall;

  // Check if the given format is enabled
  // STDMETHOD_(BOOL,IsFormatEnabled)(LPCSTR strFormat) = 0;
  function IsFormatEnabled(strFormat: LPCSTR): BOOL; stdcall;

  // Set if LAV Splitter should always completely remove the filter connected
  // to its Audio Pin when the audio stream is changed
  // STDMETHOD(SetStreamSwitchRemoveAudio)(BOOL bEnabled) = 0;
  function SetStreamSwitchRemoveAudio(bEnabled: BOOL): HResult; stdcall;

  // Query if LAV Splitter should always completely remove the filter connected
  // to its Audio Pin when the audio stream is changed
  // STDMETHOD_(BOOL,GetStreamSwitchRemoveAudio)() = 0;
  function GetStreamSwitchRemoveAudio(): BOOL; stdcall;

  // Advanced Subtitle configuration. Refer to the documentation for details.
  // If no advanced config exists, will be NULL.
  // Memory for the string will be allocated, and has to be free'ed by the
  // caller with CoTaskMemFree
  // STDMETHOD(GetAdvancedSubtitleConfig)(LPWSTR *ppAdvancedConfig) = 0;
  function GetAdvancedSubtitleConfig(out ppAdvancedConfig: LPWSTR): HResult; stdcall;

  // Advanced Subtitle configuration. Refer to the documentation for details.
  // To reset the config, pass NULL or the empty string.
  // If no subtitle language is set, the main language preference is used.
  // STDMETHOD(SetAdvancedSubtitleConfig)(LPCWSTR pAdvancedConfig) = 0;
  function SetAdvancedSubtitleConfig(pAdvancedConfig: LPCWSTR): HResult; stdcall;

  // Set if LAV Splitter should prefer audio streams for the hearing or
  // visually impaired
  // STDMETHOD(SetUseAudioForHearingVisuallyImpaired)(BOOL bEnabled) = 0;
  function SetUseAudioForHearingVisuallyImpaired(bEnabled: BOOL): HResult; stdcall;

  // Get if LAV Splitter should prefer audio streams for the hearing or
  // visually impaired
  // STDMETHOD_(BOOL,GetUseAudioForHearingVisuallyImpaired)() = 0;
  function GetUseAudioForHearingVisuallyImpaired(): BOOL; stdcall;

  // Set the maximum queue size, in megabytes
  // STDMETHOD(SetMaxQueueMemSize)(DWORD dwMaxSize) = 0;
  function SetMaxQueueMemSize(dwMaxSize: DWORD): HResult; stdcall;

  // Get the maximum queue size, in megabytes
  // STDMETHOD_(DWORD,GetMaxQueueMemSize)() = 0;
  function GetMaxQueueMemSize(): DWORD; stdcall;

  // Toggle Tray Icon
  // STDMETHOD(SetTrayIcon)(BOOL bEnabled) = 0;
  function SetTrayIcon(bEnabled: BOOL): HResult; stdcall;

  // Get Tray Icon
  // STDMETHOD_(BOOL,GetTrayIcon)() = 0;
  function GetTrayIcon(): BOOL; stdcall;

  // Toggle whether higher quality audio streams are preferred
  //  STDMETHOD(SetPreferHighQualityAudioStreams)(BOOL bEnabled) = 0;
  function SetPreferHighQualityAudioStreams(bEnabled: BOOL): HResult; stdcall;

  // Toggle whether higher quality audio streams are preferred
  // STDMETHOD_(BOOL,GetPreferHighQualityAudioStreams)() = 0;
  function GetPreferHighQualityAudioStreams(): BOOL; stdcall;

  // Toggle whether Matroska Linked Segments should be loaded from other files
  // STDMETHOD(SetLoadMatroskaExternalSegments)(BOOL bEnabled) = 0;
  function SetLoadMatroskaExternalSegments(bEnabled: BOOL): HResult; stdcall;

  // Get whether Matroska Linked Segments should be loaded from other files
  // STDMETHOD_(BOOL,GetLoadMatroskaExternalSegments)() = 0;
  function GetLoadMatroskaExternalSegments(): BOOL; stdcall;

  // Get the list of available formats
  // Memory for the string array will be allocated, and has to be free'ed by
  // the caller with CoTaskMemFree
  // STDMETHOD(GetFormats)(LPSTR** formats, UINT* nFormats) = 0;
  function GetFormats(out formats: PLPSTR; nFormats: PCardinal): HResult; stdcall;

  // Set the duration (in ms) of analysis for network streams (to find the
  // streams and codec parameters)
  // STDMETHOD(SetNetworkStreamAnalysisDuration)(DWORD dwDuration) = 0;
  function SetNetworkStreamAnalysisDuration(dwDuration: DWORD): HResult; stdcall;

  // Get the duration (in ms) of analysis for network streams (to find the
  // streams and codec parameters)
  // STDMETHOD_(DWORD, GetNetworkStreamAnalysisDuration)() = 0;
  function GetNetworkStreamAnalysisDuration(): DWORD; stdcall;

end;

implementation

end.
